import { ProFormColumnsType } from "@ant-design/pro-components";
import { useModel } from "@umijs/max";

function formConfig(): ProFormColumnsType<{
}>[] {
    let { getEnum } = useModel("global")
    return [
        {
            valueType: 'digit',
            dataIndex: "regPayIntervalTime",
            title: "注册充值回传的最大间隔时间",
            tooltip: "（超时不回传）",
            formItemProps: {
                style: { marginBottom: 10 },
                rules: [
                    {
                        required: true,
                        message: '此项为必填项',
                    },
                ],
            },
            fieldProps: {
                placeholder: '请输入数字',
                style: { width: "70%" },
                addonAfter: "分钟"
            },
        },
        {
            valueType: 'radioButton',
            dataIndex: "vipOrderBackType",
            title: "VIP回传策略",
            initialValue: 1,
            formItemProps: {
                style: { marginBottom: 10 },
                rules: [
                    {
                        required: true,
                        message: '此项为必填项',
                    },
                ],
            },
            valueEnum: getEnum("VIP_CALLBACK", "map")
        },
        {
            valueType: 'radioButton',
            dataIndex: "backUnit",
            title: "回传类型",
            initialValue: 1,
            formItemProps: {
                style: { marginBottom: 10 },
                rules: [
                    {
                        required: true,
                        message: '此项为必填项',
                    },
                ],
            },
            valueEnum: getEnum("CALLBACK_TYPE", "map")
        },
        {
            valueType: 'dependency',
            name: ["backUnit"],
            columns({ backUnit }) {
                return [
                    {
                        valueType: 'divider',
                        fieldProps: {
                            children: backUnit === 1 ? "首单" : "首日",
                            orientation: "left"
                        }
                    },
                    {
                        dataIndex: 'firstBackRate',
                        valueType: 'formList',
                        fieldProps: {
                            creatorButtonProps: {
                                creatorButtonText: "添加一个档位配置",
                            },
                            alwaysShowItemLabel: true,//全部展示title
                        },
                        colProps: {
                            span: 24
                        },
                        columns: [
                            {
                                valueType: 'group',
                                colProps: {
                                    span: 24
                                },
                                columns: [
                                    {
                                        dataIndex: 'minAmount',
                                        valueType: 'digit',
                                        title: "最小金额",
                                        tooltip: "最小金额（大于等于）",
                                        fieldProps: {
                                            placeholder: "最小金额",
                                            style: { width: "100%" },
                                        },
                                        colProps: { span: 5 },
                                        formItemProps: {
                                            style: { marginBottom: 10 },
                                            rules: [
                                                {
                                                    required: true,
                                                    message: '此项为必填项',
                                                },
                                            ],
                                        },
                                    },
                                    {
                                        dataIndex: 'maxAmount',
                                        valueType: 'digit',
                                        title: "最大金额",
                                        tooltip: "最大金额（小于）",
                                        colProps: { span: 5 },
                                        fieldProps: {
                                            placeholder: "最大金额",
                                            style: { width: "100%" },
                                        },
                                        formItemProps: {
                                            style: { marginBottom: 10 },
                                            rules: [
                                                {
                                                    required: true,
                                                    message: '此项为必填项',
                                                },
                                            ],
                                        },
                                    },
                                    {
                                        dataIndex: 'backType',
                                        valueType: 'radioButton',
                                        title: "回传方式",
                                        colProps: { span: 5, offset: 1 },
                                        initialValue: 1,
                                        formItemProps: {
                                            style: { marginBottom: 10 },
                                            rules: [
                                                {
                                                    required: true,
                                                    message: '此项为必填项',
                                                },
                                            ],
                                        },
                                        valueEnum: new Map(["比例", "概率"]?.map((text, index) => [index, text])),
                                    },
                                    {
                                        valueType: "dependency",
                                        name: ["backType"],
                                        columns(values) {
                                            let { backType } = values
                                            return [
                                                {
                                                    valueType: 'digitRange',
                                                    dataIndex: 'backRate',
                                                    title: "回传比例",
                                                    colProps: { span: 7 },
                                                    preserve:false,
                                                    convertValue: (value) => {
                                                        return typeof value === "string" ? value?.split(":") : Array.isArray(value) ? value : []
                                                    },
                                                    hideInForm: backType === 1,
                                                    formItemProps: {
                                                        style: { marginBottom: 10 },
                                                        rules: [
                                                            {
                                                                required: true,
                                                                message: '此项为必填项',
                                                            },
                                                        ],
                                                    },
                                                    valueEnum: getEnum("CALLBACK_TYPE", "map")
                                                },
                                                {
                                                    valueType: 'select',
                                                    dataIndex: "backRate",
                                                    title: "回传概率",
                                                    colProps: { span: 7 },
                                                    preserve:false,
                                                    hideInForm: backType !== 1,
                                                    convertValue: (value) => {
                                                        return typeof value === "number" ? value : 0
                                                    },
                                                    formItemProps: {
                                                        style: { marginBottom: 10 },
                                                        rules: [
                                                            {
                                                                required: true,
                                                                message: '此项为必填项',
                                                            },
                                                        ],
                                                    },
                                                    valueEnum: new Map([0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10]?.map((text) => [text * 10, text * 10 + "%"]))
                                                },
                                            ]
                                        },
                                    }
                                ]
                            }
                        ]
                    },
                ]
            },
        },
    ]
}

export default formConfig